#!/bin/bash

set -e

MARIAN=../build
MARIAN_MASTER=../build_master

SRC=en
TRG=de

mkdir -p speed_intgemm
test -e model.intgemm.avx512.bin || $MARIAN/marian-conv -f model.npz.best-bleu-detok.npz -t model.intgemm.avx512.bin -g intgemm8avx512

for i in 16 17 18 19 20 21 22; do
	sacrebleu -t wmt$i -l $SRC-$TRG --echo src > speed_intgemm/wmt$i.$SRC
	cat speed_intgemm/wmt*.$SRC > speed_intgemm/big.$SRC

	sacrebleu -t wmt$i -l $SRC-$TRG --echo ref > speed_intgemm/wmt$i.$TRG
	cat speed_intgemm/wmt*.$TRG > speed_intgemm/big.ref.$TRG

done
echo "testset size: " `wc -l speed_intgemm/big.ref.$TRG`
echo "WITH shortlist"
echo "beam1opt shortlist"
taskset -c 0	$MARIAN/marian-decoder $@ \
	    --relative-paths -m model.intgemm.avx512.bin -v vocab.spm vocab.spm \
	    -i speed_intgemm/big.$SRC -o speed_intgemm/big.$TRG \
	    --beam-size 1 --mini-batch 32 --maxi-batch 100 --maxi-batch-sort src -w 128 \
	    --skip-cost --shortlist lex.bin --cpu-threads 1 \
	    --quiet --quiet-translation --log speed_intgemm/cpu.big.log

tail -n1 speed_intgemm/cpu.big.log
sacrebleu speed_intgemm/big.ref.$TRG < speed_intgemm/big.$TRG | tee speed_intgemm/cpu.big.$TRG.bleu

echo "master shortlist"
taskset -c 0    $MARIAN_MASTER/marian-decoder $@ \
            --relative-paths -m model.intgemm.avx512.bin -v vocab.spm vocab.spm \
            -i speed_intgemm/big.$SRC -o speed_intgemm/big.$TRG \
            --beam-size 1 --mini-batch 32 --maxi-batch 100 --maxi-batch-sort src -w 128 \
            --skip-cost --shortlist lex.bin --cpu-threads 1 \
            --quiet --quiet-translation --log speed_intgemm/cpu.big.log

tail -n1 speed_intgemm/cpu.big.log
sacrebleu speed_intgemm/big.ref.$TRG < speed_intgemm/big.$TRG | tee speed_intgemm/cpu.big.$TRG.bleu

echo "WITHOUT shortlist"

echo "beam1opt, no shortlist"
taskset -c 0    $MARIAN/marian-decoder $@ \
            --relative-paths -m model.intgemm.avx512.bin -v vocab.spm vocab.spm \
            -i speed_intgemm/big.$SRC -o speed_intgemm/big.$TRG \
            --beam-size 1 --mini-batch 32 --maxi-batch 100 --maxi-batch-sort src -w 128 \
            --skip-cost --cpu-threads 1 \
            --quiet --quiet-translation --log speed_intgemm/cpu.big.log

tail -n1 speed_intgemm/cpu.big.log
sacrebleu speed_intgemm/big.ref.$TRG < speed_intgemm/big.$TRG | tee speed_intgemm/cpu.big.$TRG.bleu

echo "master, no shortlist"
taskset -c 0    $MARIAN_MASTER/marian-decoder $@ \
            --relative-paths -m model.intgemm.avx512.bin -v vocab.spm vocab.spm \
            -i speed_intgemm/big.$SRC -o speed_intgemm/big.$TRG \
            --beam-size 1 --mini-batch 32 --maxi-batch 100 --maxi-batch-sort src -w 128 \
            --skip-cost --cpu-threads 1 \
            --quiet --quiet-translation --log speed_intgemm/cpu.big.log

tail -n1 speed_intgemm/cpu.big.log
sacrebleu speed_intgemm/big.ref.$TRG < speed_intgemm/big.$TRG | tee speed_intgemm/cpu.big.$TRG.bleu
